package cn.com.infosec.asn1.crmf;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509Name;
import java.util.Enumeration;

public class CertTemplate extends ASN1Encodable {
   private DERInteger version;
   private DERInteger serialNumber;
   private AlgorithmIdentifier signingAlg;
   private X509Name issuer;
   private OptionalValidity validity;
   private X509Name subject;
   private SubjectPublicKeyInfo publicKey;
   private DERBitString issuerUID;
   private DERBitString subjectUID;
   private X509Extensions extensions;

   private CertTemplate(ASN1Sequence seq) {
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         ASN1TaggedObject var2;
         switch ((var2 = (ASN1TaggedObject)seq1.nextElement()).getTagNo()) {
            case 0:
               this.version = DERInteger.getInstance(var2, false);
               break;
            case 1:
               this.serialNumber = DERInteger.getInstance(var2, false);
               break;
            case 2:
               this.signingAlg = AlgorithmIdentifier.getInstance(var2, false);
               break;
            case 3:
               this.issuer = X509Name.getInstance(var2, false);
               break;
            case 4:
               this.validity = OptionalValidity.getInstance(ASN1Sequence.getInstance(var2, false));
               break;
            case 5:
               this.subject = X509Name.getInstance(var2, false);
               break;
            case 6:
               this.publicKey = SubjectPublicKeyInfo.getInstance(var2, false);
               break;
            case 7:
               this.issuerUID = DERBitString.getInstance(var2, false);
               break;
            case 8:
               this.subjectUID = DERBitString.getInstance(var2, false);
               break;
            case 9:
               this.extensions = X509Extensions.getInstance(var2, false);
               break;
            default:
               throw new IllegalArgumentException("unknown tag: " + var2.getTagNo());
         }
      }

   }

   public static CertTemplate getInstance(Object o) {
      if (o instanceof CertTemplate) {
         return (CertTemplate)o;
      } else if (o instanceof ASN1Sequence) {
         return new CertTemplate((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   private void addOptional(ASN1EncodableVector v, int tagNo, ASN1Encodable obj) {
      if (obj != null) {
         DERTaggedObject var4;
         var4 = new DERTaggedObject.<init>(false, tagNo, obj);
         v.add(var4);
      }

   }

   public DERObject toASN1Object() {
      CertTemplate var10000 = this;
      CertTemplate var10001 = this;
      CertTemplate var10002 = this;
      CertTemplate var10003 = this;
      CertTemplate var10004 = this;
      CertTemplate var10005 = this;
      CertTemplate var10006 = this;
      CertTemplate var10007 = this;
      CertTemplate var10008 = this;
      CertTemplate var10009 = this;
      CertTemplate var10010 = this;
      CertTemplate var10011 = this;
      CertTemplate var10012 = this;
      CertTemplate var10013 = this;
      CertTemplate var10014 = this;
      CertTemplate var10015 = this;
      CertTemplate var10016 = this;
      CertTemplate var10017 = this;
      CertTemplate var10018 = this;
      CertTemplate var10019 = this;
      ASN1EncodableVector var2;
      var2 = new ASN1EncodableVector.<init>();
      DERInteger var1 = var10019.version;
      var10018.addOptional(var2, 0, var1);
      var1 = var10017.serialNumber;
      var10016.addOptional(var2, 1, var1);
      AlgorithmIdentifier var3 = var10015.signingAlg;
      var10014.addOptional(var2, 2, var3);
      X509Name var4 = var10013.issuer;
      var10012.addOptional(var2, 3, var4);
      OptionalValidity var5 = var10011.validity;
      var10010.addOptional(var2, 4, var5);
      var4 = var10009.subject;
      var10008.addOptional(var2, 5, var4);
      SubjectPublicKeyInfo var6 = var10007.publicKey;
      var10006.addOptional(var2, 6, var6);
      DERBitString var7 = var10005.issuerUID;
      var10004.addOptional(var2, 7, var7);
      var7 = var10003.subjectUID;
      var10002.addOptional(var2, 8, var7);
      X509Extensions var8 = var10001.extensions;
      var10000.addOptional(var2, 9, var8);
      return new DERSequence(var2);
   }
}
